@@ -48,7 +48,8 @@ class OAuthTwitter(object):
         User account.
         """
         self.auto_create_user = auto_create_user
-        if association_url is None:
+        self._association_url_default = association_url is None
+        if self._association_url_default:
             self.association_url = LazyReverse(self.associate)
         else:
             self.association_url = LazyReverse(association_url)
@@ -72,13 +73,13 @@ class OAuthTwitter(object):
             url(r'^callback/', self.callback, name='twitter_callback'),
             url(r'^signin/', self.signin, name='twitter_signin'),
         )
-        if self.association_url.location == self.associate:
+        if self._association_url_default:
             # Add ^associate/ location if we're meant to handle association.
             urlpatterns += patterns('',
                 url(r'^associate/signin/', self.signin,
-                    kwargs={'success_url': self.association_url.location},
+                    kwargs={'success_url': 'twitter_associate'},
                     name='twitter_signin_associate'),
-                url(r'^associate/', self.association_url.location,
+                url(r'^associate/', self.associate,
                     name='twitter_associate'),
             )
         if self.registration_url.location == self.register:
@@ -90,6 +91,7 @@ class OAuthTwitter(object):
         return urlpatterns
     urls = property(get_urls)
 
+    @login_required
     def associate(self, request,
                   template="django_oauth_twitter/associate.html",
                   dictionary=None):
